@@ -6,6 +6,8 @@
 import collections
 import enum
 import fnmatch
+import functools
+import operator
 import os
 import re
 import warnings
@@ -280,7 +282,13 @@ def preprocess_text(text):
     ...     preprocess_text('min_tls_version=TLS1.3')
     'protocol@TLS = -SSL2.0 -SSL3.0 -TLS1.0 -TLS1.1 -TLS1.2'
     """
-    text = re.sub(r'#.*', '', text)
+    magic_comments = {
+        '# %suppress_experimental_value_warnings=true',
+        '# %suppress_experimental_value_warnings=false',
+    }
+    text = re.sub(r'#.*',
+                  lambda s: s.group(0) if s.group(0) in magic_comments else '',
+                  text)
     text = text.replace('=', ' = ')
     text = '\n'.join(l.strip() for l in text.split('\n'))
     text = text.replace('\\\n', '')
@@ -450,6 +458,24 @@ class UnscopedCryptoPolicy:
     def scoped(self, scopes=None):
         return ScopedPolicy(self._directives, scopes or {})
 
+    @staticmethod
+    def _for_in_lines_expwarn(lines, func):
+        warn_on_experimental = True  # reset between invocations
+        ExpValWarning = validation.alg_lists.ExperimentalValueWarning
+        r = []
+        for l in lines:
+            if l == '# %suppress_experimental_value_warnings = true':
+                warn_on_experimental = False
+            elif l == '# %suppress_experimental_value_warnings = false':
+                warn_on_experimental = True
+            elif warn_on_experimental:
+                r.append(func(l))
+            else:
+                with warnings.catch_warnings(append=True):
+                    warnings.filterwarnings('ignore', category=ExpValWarning)
+                    r.append(func(l))
+        return r
+
     def read_policy_file(self, name, subpolicy=False):
         pdir = self.policydir or 'policies'
         if subpolicy:
@@ -466,11 +492,16 @@ class UnscopedCryptoPolicy:
             text = f.read()
         text = preprocess_text(text)
         lines = text.split('\n')
-        for l in lines:  # display several warnings at once
-            syntax_check_line(l, warn=True)
-        for l in lines:  # crash
-            syntax_check_line(l)
-        return [x for l in lines for x in parse_line(l)]
+        # display several warnings at once, if there are any
+        self._for_in_lines_expwarn(lines,
+                                   lambda l: syntax_check_line(l, warn=True))
+        # crash, if there are any
+        self._for_in_lines_expwarn(lines, syntax_check_line)
+
+        # return [x for l in lines for x in parse_line(l)],  # noqa: ERA001
+        # but with configurable experimental value warnings uppression
+        r = self._for_in_lines_expwarn(lines, parse_line)
+        return functools.reduce(operator.iadd, r)
 
     def __str__(self):
         def fmt(key, value):
